@@ -615,8 +615,8 @@ def construct_invocation_event(
         "body": data,
         "isBase64Encoded": is_base64_encoded,
         "httpMethod": method,
-        "queryStringParameters": query_string_params,
-        "multiValueQueryStringParameters": multi_value_dict_for_list(query_string_params),
+        "queryStringParameters": query_string_params or None,
+        "multiValueQueryStringParameters": multi_value_dict_for_list(query_string_params) or None,
     }
 
 
