@@ -67,6 +67,8 @@ from localstack.aws.api.dynamodb import (
     TagKeyList,
     TagList,
     TimeToLiveSpecification,
+    TransactGetItemList,
+    TransactGetItemsOutput,
     TransactWriteItemsInput,
     TransactWriteItemsOutput,
     UpdateGlobalTableOutput,
@@ -397,6 +399,7 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
 
         # forward request to backend
         result = self.forward_request(context)
+        table_description = result["TableDescription"]
 
         backend = DynamoDBRegion.get()
         backend.table_definitions[table_name] = table_definitions = dict(create_table_input)
@@ -411,20 +414,21 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
         if table_definitions:
             table_content = result.get("Table", {})
             table_content.update(table_definitions)
-            result["TableDescription"].update(table_content)
+            table_description.update(table_content)
 
         if "StreamSpecification" in table_definitions:
-            create_dynamodb_stream(
-                table_definitions, result["TableDescription"].get("LatestStreamLabel")
-            )
+            create_dynamodb_stream(table_definitions, table_description.get("LatestStreamLabel"))
 
         tags = table_definitions.pop("Tags", [])
-        result["TableDescription"].pop("Tags", None)
         if tags:
-            table_arn = result["TableDescription"]["TableArn"]
+            table_arn = table_description["TableArn"]
             table_arn = self.fix_table_arn(table_arn)
             DynamoDBRegion.TABLE_TAGS[table_arn] = {tag["Key"]: tag["Value"] for tag in tags}
 
+        # remove invalid attributes from result
+        table_description.pop("Tags", None)
+        table_description.pop("BillingMode", None)
+
         event_publisher.fire_event(
             event_publisher.EVENT_DYNAMODB_CREATE_TABLE,
             payload={"n": event_publisher.get_hash(table_name)},
@@ -765,6 +769,15 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
 
         return result
 
+    @handler("TransactGetItems", expand=False)
+    def transact_get_items(
+        self,
+        context: RequestContext,
+        transact_items: TransactGetItemList,
+        return_consumed_capacity: ReturnConsumedCapacity = None,
+    ) -> TransactGetItemsOutput:
+        return self.forward_request(context)
+
     @handler("ExecuteStatement", expand=False)
     def execute_statement(
         self,
@@ -1284,7 +1297,7 @@ def has_event_sources_or_streams_enabled(table_name: str, cache: Dict = None):
 
     # if kinesis streaming destination is enabled
     # get table name from table_arn
-    # since batch_wrtie and transact write operations passing table_arn instead of table_name
+    # since batch_write and transact write operations passing table_arn instead of table_name
     table_name = table_arn.split("/", 1)[-1]
     table_definitions = DynamoDBRegion.get().table_definitions
     if not result and table_definitions.get(table_name):
