@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import functools
 import json
 import logging
@@ -7,7 +9,7 @@ import socket
 import ssl
 import threading
 from asyncio.selector_events import BaseSelectorEventLoop
-from typing import Dict, List, Match, Optional, Union
+from typing import Dict, List, Match, Optional, Type, TypeVar, Union
 from urllib.parse import parse_qs, unquote, urlencode, urlparse
 
 import requests
@@ -32,6 +34,7 @@ from localstack.constants import (
     APPLICATION_JSON,
     AWS_REGION_US_EAST_1,
     BIND_HOST,
+    HEADER_LOCALSTACK_AUTHORIZATION,
     HEADER_LOCALSTACK_REQUEST_URL,
 )
 from localstack.services.messages import Headers, MessagePayload
@@ -111,6 +114,8 @@ ALLOWED_CORS_ORIGINS = [
     f"http://localhost.localstack.cloud:{config.EDGE_PORT}",
     "https://localhost",
     "https://localhost.localstack.cloud",
+    # for requests from Electron apps, e.g., DynamoDB NoSQL Workbench
+    "file://",
 ]
 if EXTRA_CORS_ALLOWED_ORIGINS:
     ALLOWED_CORS_ORIGINS += EXTRA_CORS_ALLOWED_ORIGINS.split(",")
@@ -343,17 +348,19 @@ class ArnPartitionRewriteListener(MessageModifyingProxyListener):
 # BASE BACKEND UTILS
 # -------------------
 
+T = TypeVar("T", bound="RegionBackend")
+
 
 class RegionBackend(object):
     """Base class for region-specific backends for the different APIs.
     RegionBackend lookup methods are not thread safe."""
 
-    REGIONS: Dict[str, "RegionBackend"]
+    REGIONS: Dict[str, T]
 
     name: str  # name of the region
 
     @classmethod
-    def get(cls, region: str = None) -> "RegionBackend":
+    def get(cls: Type[T], region: str = None) -> T:
         region = region or cls.get_current_request_region()
 
         regions = cls.regions()
@@ -366,7 +373,7 @@ class RegionBackend(object):
         return regions[region]
 
     @classmethod
-    def regions(cls) -> Dict[str, "RegionBackend"]:
+    def regions(cls: Type[T]) -> Dict[str, T]:
         if not hasattr(cls, "REGIONS"):
             # maps region name to region backend instance
             cls.REGIONS = {}
@@ -961,8 +968,8 @@ def start_proxy_server(
         method = request.method
         headers = request.headers
         headers[HEADER_LOCALSTACK_REQUEST_URL] = str(request.url)
-
-        response = modify_and_forward(
+        headers[HEADER_LOCALSTACK_AUTHORIZATION] = headers.get("Authorization", "")
+        return modify_and_forward(
             method=method,
             path=path_with_params,
             data_bytes=data,
@@ -973,8 +980,6 @@ def start_proxy_server(
             server_address=parsed_url.netloc,
         )
 
-        return response
-
     ssl_creds = (None, None)
     if use_ssl:
         install_predefined_cert_if_available()
