@@ -10,7 +10,7 @@ import tempfile
 from abc import ABCMeta, abstractmethod
 from enum import Enum, unique
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Dict, List, Optional, Protocol, Tuple, Union
 
 from localstack import config
 from localstack.utils.collections import HashableList
@@ -77,6 +77,19 @@ class AccessDenied(ContainerException):
         self.object_name = object_name
 
 
+class CancellableStream(Protocol):
+    """Describes a generator that can be closed. Borrowed from ``docker.types.daemon``."""
+
+    def __iter__(self):
+        raise NotImplementedError
+
+    def __next__(self):
+        raise NotImplementedError
+
+    def close(self):
+        raise NotImplementedError
+
+
 class PortMappings(object):
     """Maps source to target port ranges for Docker port mappings."""
 
@@ -449,6 +462,11 @@ class ContainerClient(metaclass=ABCMeta):
         """Get all logs of a given container"""
         pass
 
+    @abstractmethod
+    def stream_container_logs(self, container_name_or_id: str) -> CancellableStream:
+        """Returns a blocking generator you can iterate over to retrieve log output as it happens."""
+        pass
+
     @abstractmethod
     def inspect_container(self, container_name_or_id: str) -> Dict[str, Union[Dict, str]]:
         """Get detailed attributes of an container.
